<?php

namespace App\Entity;

use App\Repository\FindingRepository;
use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: FindingRepository::class)]
#[ORM\Table(name: 'rinvenimento')]
class Finding implements \JsonSerializable
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 200, name: 'oggetto')]
    private ?string $object = null;

    #[ORM\Column(length: 200, nullable: true, name: 'materia')]
    private ?string $material = null;

    #[ORM\Column(length: 100, nullable: true, name: 'luogo_rinv')]
    private ?string $place = null;

    #[ORM\Column(nullable: true, name: 'anno_rinv', length: 40)]
    private ?string $year = null;

    #[ORM\Column(length: 200, nullable: true, name: 'datazione')]
    private ?string $dating = null;

    #[ORM\Column(type: Types::BIGINT, nullable: true, name: 'sito')]
    #[ORM\ManyToOne(Site::class)]
    private ?string $site = null;

    #[ORM\Column(length: 255, nullable: true, name: 'stato_conserv')]
    private ?string $conservationState = null;

    #[ORM\Column(length: 255, nullable: true, name: 'luogo_conserv')]
    private ?string $conservationPlace = null;

    #[ORM\Column(type: Types::TEXT, nullable: true, name: 'descrizione')]
    private ?string $description = null;

    #[ORM\Column(length: 255, nullable: true, name: 'autore_scheda')]
    private ?string $author = null;

    #[ORM\Column(length: 40, nullable: true, name: 'misure')]
    private ?string $measurements = null;

    #[ORM\Column(name: 'comune', length: 10, nullable: false)]
    private ?string $municipality = null;

    #[ORM\Column(name: 'etichetta', length: 150, nullable: false)]
    private ?string $label = null;

    private ?float $lat = null;

    private ?float $lng = null;

    /**
     * @var Bibliography[] $bibliography
     */
    private ?array $bibliography = null;

    /**
     * @var Image[] $images
     */
    private ?array $images = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function setId(string $id): static
    {
        $this->id = $id;

        return $this;
    }

    public function getObject(): ?string
    {
        return $this->object;
    }

    public function setObject(string $object): static
    {
        $this->object = $object;

        return $this;
    }

    public function getMaterial(): ?string
    {
        return $this->material;
    }

    public function setMaterial(?string $material): static
    {
        $this->material = $material;

        return $this;
    }

    public function getPlace(): ?string
    {
        return $this->place;
    }

    public function setPlace(?string $place): static
    {
        $this->place = $place;

        return $this;
    }

    public function getYear(): ?string
    {
        return $this->year;
    }

    public function setYear(?string $year): static
    {
        $this->year = $year;

        return $this;
    }

    public function getDating(): ?string
    {
        return $this->dating;
    }

    public function setDating(?string $dating): static
    {
        $this->dating = $dating;

        return $this;
    }

    public function getSite(): ?string
    {
        return $this->site;
    }

    public function setSite(?string $site): static
    {
        $this->site = $site;

        return $this;
    }

    public function getConservationState(): ?string
    {
        return $this->conservationState;
    }

    public function setConservationState(?string $conservationState): static
    {
        $this->conservationState = $conservationState;

        return $this;
    }

    public function getConservationPlace(): ?string
    {
        return $this->conservationPlace;
    }

    public function setConservationPlace(?string $conservationPlace): static
    {
        $this->conservationPlace = $conservationPlace;

        return $this;
    }

    public function getDescription(): ?string
    {
        return $this->description;
    }

    public function setDescription(?string $description): static
    {
        $this->description = $description;

        return $this;
    }

    public function getAuthor(): ?string
    {
        return $this->author;
    }

    public function setAuthor(string $author): static
    {
        $this->author = $author;

        return $this;
    }

    public function getMeasurements(): ?string
    {
        return $this->measurements;
    }

    public function setMeasurements(?string $measurements): static
    {
        $this->measurements = $measurements;

        return $this;
    }

    public function getLabel(): ?string
    {
        return $this->label;
    }

    public function setLabel(?string $label): static
    {
        $this->label = $label;

        return $this;
    }

    public function getMunicipality(): ?string
    {
        return $this->municipality;
    }

    public function setMunicipality(?string $municipality): static
    {
        $this->municipality = $municipality;

        return $this;
    }

    public function getLat(): ?float
    {
        return $this->lat;
    }

    public function setLat(float $lat): static
    {
        $this->lat = $lat;

        return $this;
    }

    public function getLng(): ?float
    {
        return $this->lng;
    }

    public function setLng(float $lng): static
    {
        $this->lng = $lng;

        return $this;
    }

    public function getBibliography(): ?array
    {
        return $this->bibliography;
    }

    public function setBibliography(array $bibliography): static
    {
        $this->bibliography = $bibliography;

        return $this;
    }

    public function getImages(): ?array
    {
        return $this->images;
    }

    public function setImages(array $images): static
    {
        $this->images = $images;

        return $this;
    }

    public function jsonSerialize(): array
    {
        return [
            'id' => $this->id,
            'object' => $this->object,
            'material' => $this->material,
            'measurements' => $this->measurements,
            'place' => $this->place,
            'year' => $this->year,
            'dating' => $this->dating,
            'conservationState' => $this->conservationState,
            'conservationPlace' => $this->conservationPlace,
            'description' => $this->description,
            'author' => $this->author,
            'label' => $this->label,
            'municipality' => $this->municipality,
            'coordinates' => [$this->lat, $this->lng],
            'bibliography' => $this->bibliography,
            'images' => $this->images,
        ];
    }
}
