<?php

namespace App\Repository;

use App\Entity\Document;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Persistence\ManagerRegistry;
use Doctrine\ORM\Query\ResultSetMappingBuilder;

/**
 * @extends ServiceEntityRepository<Document>
 */
class DocumentRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, Document::class);
    }

    /**
    * @return Document[] Returns an array of Document objects
    */
    public function findBySite(int $siteId): array
    {
        $conn = $this->getEntityManager()->getConnection();

        $sql = '
            SELECT 
                d.id,
                d.titolo,
                d.filename,
                d.descrizione,
                d.autori,
                d.tipo,
                d.luogo
            FROM documento d
            INNER JOIN sito_documento sd ON sd.id_documento = d.id
            WHERE sd.id_sito = :siteId
            ORDER BY d.titolo ASC
        ';

        $stmt = $conn->prepare($sql);
        $results = $stmt->executeQuery(['siteId' => $siteId])->fetchAllAssociative();

        $entities = [];

        foreach ($results as $row) {
            $document = new Document();
            $document->setId($row['id']);
            $document->setTitle($row['titolo']);
            $document->setFilename($row['filename']);
            $document->setDescription($row['descrizione']);
            $document->setConservationPlace($row['luogo']);
            $document->setType($row['tipo']);
            $document->setAuthors($row['autori']);
            $entities[] = $document;
        }

        return $entities;
    }

    /**
    * @return Document[] Returns an array of Document objects
    */
    public function findByNotConserved(int $notConservedId): array
    {
        $conn = $this->getEntityManager()->getConnection();

        $sql = '
            SELECT 
                d.id,
                d.titolo,
                d.filename,
                d.descrizione,
                d.autori,
                d.tipo,
                d.luogo
            FROM documento d
            INNER JOIN non_conserv_documento sd ON sd.id_documento = d.id
            WHERE sd.id_non_conserv = :notConservedId
            ORDER BY d.titolo ASC
        ';

        $stmt = $conn->prepare($sql);
        $results = $stmt->executeQuery(['notConservedId' => $notConservedId])->fetchAllAssociative();

        $entities = [];

        foreach ($results as $row) {
            $document = new Document();
            $document->setId($row['id']);
            $document->setTitle($row['titolo']);
            $document->setFilename($row['filename']);
            $document->setDescription($row['descrizione']);
            $document->setConservationPlace($row['luogo']);
            $document->setType($row['tipo']);
            $document->setAuthors($row['autori']);
            $entities[] = $document;
        }

        return $entities;
    }
    //    /**
    //     * @return Document[] Returns an array of Document objects
    //     */
    //    public function findByExampleField($value): array
    //    {
    //        return $this->createQueryBuilder('d')
    //            ->andWhere('d.exampleField = :val')
    //            ->setParameter('val', $value)
    //            ->orderBy('d.id', 'ASC')
    //            ->setMaxResults(10)
    //            ->getQuery()
    //            ->getResult()
    //        ;
    //    }

    //    public function findOneBySomeField($value): ?Document
    //    {
    //        return $this->createQueryBuilder('d')
    //            ->andWhere('d.exampleField = :val')
    //            ->setParameter('val', $value)
    //            ->getQuery()
    //            ->getOneOrNullResult()
    //        ;
    //    }
}
